#!/usr/bin/python3
#-*- coding : Utf-8 -*-

import matplotlib.pyplot as mpl #MODIF
import numpy as np
import random

# Quelques constantes pour faciliter la lecture du code :

# Codage des elements :
ARBRE         = 3
FEU           = 2
CENDRE        = 1
INCOMBUSTIBLE = 0

# Les variables / constantes globales :
N = 20		     # dimension du tableau
tab = np.zeros((N,N))	# On initialise le tableau avec des zeros

def cartesien (E,F):  #MODIF
    return [[x,y] for x in E for y in F] 
    
def initTableau(proportion = 0.6): 	# initialisation aleatoire du tableau
    global tab
    tab = np.zeros((N,N))
    for col,lig in cartesien(range(1,N-1),range(1,N-1)) :
        if random.random()<proportion :
            tab[lig,col] = ARBRE

    for i in range(1,N-1):
        tab[1,i] = FEU

        
def evolution():	# La boucle principale qui gere l'evolution
    inFire0 = [] # liste des zones en feu à l'instant t
    inFire1 = [] # liste des zones en feu à l'instant t+1
    for i,j in cartesien(range(1,N-1), range(1,N-1)):
        if tab[i,j] == FEU :
            inFire0.append((i,j))

    while inFire0 : # MODIF
        for (i,j) in inFire0 :
            tab[i,j] = CENDRE
            for (dy,dx) in [(-1,0), (1,0),(0,-1),(0,1)] :
                if tab[i+dy,j+dx] == ARBRE :
                    tab[i+dy,j+dx] = FEU
                    inFire1.append((i+dy,j+dx))
        inFire0 = inFire1.copy()
        inFire1 = []
    # MODIF : on teste si le feu a traverse
    for i in range(1,N-1) :
        if tab[N-2,i] == CENDRE :
            return True
    return False

# MODIFS : 
def proba(t_ech,prop):
    """ approche statistique de la proba de traverser la foret """
    s = 0
    for i in range(t_ech):
        initTableau(prop)
        if evolution() : 
            s += 1
    return s/t_ech
    
X = np.linspace(0,1,51)
Y = []
for x in X :
    y = proba(t_ech=50,prop=x)
    Y.append(y)
    print(x,y)
    
mpl.plot(X,Y)
mpl.ylim(-0.2,1.2)
mpl.show()






